@@ -463,7 +463,7 @@ class SentryService(BaseServices):
             if link.text.strip() == companyName and "nuwa/teams" in link.attrs['href']:
                 created = True
                 break
-         
+        
         # create team 
         if not created:
             browser.open("%s/organizations/nuwa/teams/new/" % SENTRY_URL)
@@ -482,8 +482,10 @@ class SentryService(BaseServices):
         created = False
         for link in browser.page.select('a'):
             if link.text.strip() == projectName and "nuwa/" in link.attrs['href']:
-                created = True
-                break
+                if not "teams" in link.attrs['href']:
+                    if link.parent.parent.parent.h3.select('a')[3].text.strip() == companyName:
+                        created = True
+                        break
         
         # create project
         if not created:
@@ -503,10 +505,13 @@ class SentryService(BaseServices):
         # get dsn
         projectURL = None
         
+        browser.open("%s/nuwa/" % SENTRY_URL)
         for link in browser.page.select('a'):
             if link.text.strip() == projectName and "nuwa/" in link.attrs['href']:
-                projectURL = link.attrs['href']
-                break
+                if not "teams" in link.attrs['href']:
+                    if link.parent.parent.parent.h3.select('a')[3].text.strip() == companyName:
+                        projectURL = link.attrs['href']
+                        break
         
         browser.open("%s%ssettings/keys/" % (SENTRY_URL, projectURL))
         
